import { Ref } from 'vue';
/** 待配置参数的描述信息 */
export interface ParameterDescriptor {
    /** 参数编号 */
    id: string;
    /** 参数标题 */
    label: string;
    /** 参数描述 */
    description?: string;
    /** 默认值 */
    defaultValue?: any;
    /** 编辑器类型 */
    editorType?: string;
}
/** 参数条目 */
export interface ParameterItem {
    /** 唯一标识 */
    id: string;
    /** 参数编号 */
    code: string;
    /** 参数值 */
    value: any;
    /** 编辑器类型 */
    editorType?: string;
}
/**
 * 表单上下文数据
 * @description 需要传递给通用参数编辑器组件
 */
export interface FormContextData {
    fieldData?: any[];
    varData?: any[];
    formData?: any[];
}
export interface UseParameters {
    parameterItems: Ref<ParameterItem[]>;
    parameterCodeOptions: Ref<{
        id: string;
        name: string;
    }[]>;
    formContextData: Ref<FormContextData>;
    parameterDescriptors: Ref<ParameterDescriptor[]>;
    initialize: () => void;
    onParameterCodeChanged: (parameterItemId: string) => void;
    hasDuplicateParameter: () => boolean;
    deleteParameterById: (parameterItemId: string) => void;
    appendNewParameter: () => void;
    getNewValue: () => string;
}
