import { Ref } from "vue";
import { PropertyType } from "../property-editor.props";
/**
 * 属性类型的枚举选项
 */
export interface PropertyTypeItem {
    /** 属性类型:const、variable、custom、stateMachine、expression */
    id: PropertyType;
    /** 属性类型的显示名称 */
    name: string;
}
/**
 * 常量值的枚举选项
 */
export interface ConstEnumItem {
    /** 枚举项的键值 */
    id: any;
    /** 枚举项的名称 */
    name: string;
}
/**
 * 变量属性值
 */
export interface VariableValue {
    type: 'Variable';
    /** 变量唯一标识 */
    field: string;
    /** 变量绑定路径 */
    path: string;
    /** 包含层级结构的变量路径 */
    fullPath: string;
    /** 是否为新增的变量 */
    isNewVariable?: boolean;
    /** 新变量的类型 */
    newVariableType?: 'String' | 'Number' | 'Boolean' | 'Date' | 'DateTime' | 'Text' | 'Object' | 'Array';
}
/**
 * 变量数据的类型
 */
export interface VariableItem {
    /** 变量内码 */
    field: string;
    /** 变量绑定路径 */
    path: string;
    /** 包含层级结构的变量路径 */
    fullPath: string;
}
/**
 * 状态机属性值
 */
export interface StateMachineValue {
    type: 'StateMachine';
    /** 状态机标识 */
    field: string;
    /** 状态机前缀状态 */
    status: boolean;
}
/**
 * 状态机数据的类型
 */
export interface StateMachineItem {
    /** 状态机内码 */
    id: string;
    /** 状态机的显示名称 */
    name: string;
}
/**
 * 表达式的信息
 */
export interface ExpressionInfo {
    /** 表达式的规则值 */
    value: string;
    /** 表达式的提示信息 */
    message?: string;
    /** 表达式目标控件的标识 */
    targetId: string;
    /** 表达式目标控件的类型 */
    targetType: string;
    /** 表达式的类型 */
    expressionType: string;
}
/**
 * 表达式属性值
 */
export interface ExpressionValue {
    type: 'Expression';
    /** 表达式标识 */
    expressionId: string;
    /** 表达式信息，用于往expressions节点存储 */
    expressionInfo: ExpressionInfo;
}
export interface UsePropertyValue {
    triggerValueChange: (newValue: any) => void;
    getPropertyValue: (propertyType: PropertyType) => Ref<any>;
    isPropertyValueValid: (propertyType: PropertyType, propertyValue: any) => boolean;
}
export interface UsePropertyType {
    getAllowedPropertyTypeItems: () => Ref<PropertyTypeItem[]>;
    getCurrentPropertyType: () => Ref<PropertyType>;
}
export interface UseStateMachine {
    getStateMachineValue: () => Ref<StateMachineValue>;
}
export interface UseVariable {
    generateVariable: () => VariableValue;
    getVariableByPath: (variablePath: string) => VariableValue;
    getVariableValue: () => Ref<VariableValue>;
}
export interface UsePropertyEditor {
    getVariables: (viewModelId: string) => VariableItem[];
    getControlName: (propertyData: any) => string;
    getStateMachines: () => StateMachineItem[];
}
export interface UseExpression {
    getExpressionValue: () => Ref<ExpressionValue>;
}
