import { BaseControlProperty } from "./base-property";
import { DesignerComponentInstance } from "../../../../designer-canvas/src/types";
import { FormPropertyChangeObject } from "../type";
import { UseResponseLayoutEditorSetting } from '../../../../response-layout-editor';
import { FormVariable } from '../../../../common';
export declare class InputBaseProperty extends BaseControlProperty {
    responseLayoutEditorFunction: UseResponseLayoutEditorSetting;
    /** 控件绑定的变量 */
    bindingVarible?: FormVariable;
    constructor(componentId: string, designerHostService: any);
    private getCommonPropertyConfig;
    getPropertyConfig(propertyData: any, componentInstance: DesignerComponentInstance): {
        type: string;
        categories: {};
    };
    getGridFieldEdtiorPropConfig(propertyData: any, componentInstance: DesignerComponentInstance | null): {};
    getBasicProperties(propertyData: any, componentInstance: any): any;
    /**
     * 校验控件是否支持切换类型
     * @param control 控件
     */
    private checkCanChangeControlType;
    /**
     * 获取可选的编辑器类型
     */
    private getAvailableEditorType;
    changeBindingField(propertyData: any, changeObject: FormPropertyChangeObject, paramters?: any): any;
    getAppearanceProperties(propertyData: any, componentInstance: any): any;
    getEditorProperties(propertyData: any): any;
    /**
     * 卡片控件：切换控件类型后事件
     * @param propertyData 控件DOM属性
     * @param newControlType 新控件类型
     */
    private changeControlType;
    getComponentConfig(propertyData: any, info?: {}, properties?: {}, setPropertyRelates?: (changeObject: any, propertyData: any, parameters: any) => any): {
        properties: {
            readonly: {
                description: string;
                title: string;
                editor: {
                    type: string;
                    propertyTypes: any;
                };
            };
            required: {
                description: string;
                title: string;
                type: string;
                editor: {
                    type: string;
                    propertyTypes: any;
                };
            };
            placeholder: {
                description: string;
                title: string;
                type: string;
            };
        };
        setPropertyRelates(changeObject: any, parameters: any): void;
        description: string;
        title: string;
        type: string;
        $converter: string;
    };
    /**
   * 修改某一输入控件的样式后更新Form的统一布局配置
   * @param controlClass 控件样式
   * @param controlId 控件Id
   * @param componentId 控件所在组件id
   */
    private updateUnifiedLayoutAfterControlChanged;
    /**
     * 修改控件布局配置后更新Form统一布局配置
     * @param componentId 组件Id
     * @param controlLayoutConfig 某单独变动的控件配置项，FormResponseLayoutContext类型
     */
    private updateUnifiedLayoutAfterResponseLayoutChanged;
    /**
     * 校验宽度样式值是否一致
     */
    private checkIsUniqueColumn;
    /**
     * 枚举项编辑器
     * @param propertyData
     * @param valueField
     * @param textField
     * @returns
     */
    protected getItemCollectionEditor(propertyData: any, valueField: any, textField: any): {
        editor: {
            columns: {
                field: any;
                title: string;
                dataType: string;
            }[];
            type: string;
            valueField: any;
            nameField: any;
            requiredFields: any[];
            uniqueFields: any[];
            readonly: boolean;
        };
    };
    /**
  * 判断枚举数据是否只读
  * 1、没有绑定信息或者绑定变量，可以新增、删除、修改
  * 2、绑定类型为字段，且字段为枚举字段，则不可新增、删除、修改枚举值。只能从be修改然后同步到表单上。
  * @param propertyData 下拉框控件属性值
  */
    protected checkEnumDataReadonly(propertyData: any): boolean;
    /**
    * 将字段值变化前事件、变化后事件追加到交互面板
    * 注意：因为绑定字段值变化后事件与下拉框的值变化事件(valueChanged)重名，所以这里将事件label都重命名下
    */
    appendFieldValueChangeEvents(propertyData: any, eventList: any[]): void;
    private getControlMethodType;
    /**
    * 组装输入类控件的交互面板：包含标签超链、绑定字段值变化前后事件等。
    * @param propertyData 属性值
    * @param viewModelId 视图模型id
    * @param showPosition 面板展示位置
    * @param customEvent 输入控件特有的事件配置
    */
    getEventPropertyConfig(propertyData: any, showPosition?: string, customEventList?: {
        label: string;
        name: string;
    }[], setPropertyRelates?: (changeObject: any, data: any, parameters: any) => void): {
        title: string;
        hideTitle: boolean;
        properties: {};
        tabId: string;
        tabName: string;
        setPropertyRelates(changeObject: FormPropertyChangeObject, data: any): void;
    };
    getExpressionConfig(propertyData: any, type: 'Field' | 'Button' | 'Container', expressionTypes?: string[], associationCallBack?: (rule: Record<string, any>) => void): {
        description: string;
        title: string;
        properties: {
            [x: string]: any;
        };
    };
}
